@@ -35,7 +35,7 @@ var _ MigratorConfig = (*MultiStateMigratorConfig)(nil)
 // NewMigrator returns a new instance of MultiStateMigrator.
 func (c *MultiStateMigratorConfig) NewMigrator(o *MigratorOption) (Migrator, error) {
 	if len(c.Actions) == 0 {
-		return nil, fmt.Errorf("faild to NewMigrator with no actions")
+		return nil, fmt.Errorf("failed to NewMigrator with no actions")
 	}
 
 	// build actions from config.
@@ -107,14 +107,14 @@ func NewMultiStateMigrator(fromDir string, toDir string, fromWorkspace string, t
 // the Migrator interface between a single and multi state migrator.
 func (m *MultiStateMigrator) plan(ctx context.Context) (*tfexec.State, *tfexec.State, error) {
 	// setup fromDir.
-	fromCurrentState, fromSwitchBackToRemoteFunc, err := setupWorkDir(ctx, m.fromTf, m.fromWorkspace, m.o.IsBackendTerraformCloud)
+	fromCurrentState, fromSwitchBackToRemoteFunc, err := setupWorkDir(ctx, m.fromTf, m.fromWorkspace, m.o.IsBackendTerraformCloud, m.o.BackendConfig)
 	if err != nil {
 		return nil, nil, err
 	}
 	// switch back it to remote on exit.
 	defer fromSwitchBackToRemoteFunc()
 	// setup toDir.
-	toCurrentState, toSwitchBackToRemoteFunc, err := setupWorkDir(ctx, m.toTf, m.toWorkspace, m.o.IsBackendTerraformCloud)
+	toCurrentState, toSwitchBackToRemoteFunc, err := setupWorkDir(ctx, m.toTf, m.toWorkspace, m.o.IsBackendTerraformCloud, m.o.BackendConfig)
 	if err != nil {
 		return nil, nil, err
 	}
